@@ -29,7 +29,7 @@
 #include <string.h>
 
 /* Version */
-#define VERSION	"1.4"
+#define VERSION	"1.5"
 
 /* Shell to fall back on if no other shell can be found */
 #define DEFAULT_SHELL	"/bin/bash"
@@ -119,8 +119,11 @@ int set_unaligned(int prctl_val)
 		}
 	}
 	if (retval == -1) {
-		fprintf(stderr, "Failed to %s \"unalign\" value: %s\n",
-			((prctl_val == -1)?"get":"set"), strerror(errno));
+		if (errno == EINVAL)
+			fprintf(stderr, "ERROR: Kernel on this platform may not implement this prctl feature.\n");
+		else
+			fprintf(stderr, "Failed to %s \"unalign\" value: %s\n",
+				((prctl_val==-1)?"get":"set"),strerror(errno));
 	}
 	return(retval);
 }
@@ -173,15 +176,14 @@ int set_fpemu(int prctl_val)
 	/*
 	 * If this was a PR_GET_FPEMU operation and the error is EINVAL,
 	 * this platform does not implement PR_GET_FPEMU (It may be
-	 * implemented only on IA64 platforms). Do not complain in that
-	 * case.
+	 * implemented only on IA64 platforms). 
 	 */
-	if ((retval == -1) && ((prctl_val != -1) || (errno != EINVAL))) {
-		fprintf(stderr, "Failed to %s \"fpemu\" value: %s\n",
-			((prctl_val == -1)?"get":"set"), strerror(errno));
-		if ((prctl_val != -1) && (errno ==EINVAL)) {
-			fprintf(stderr, "   Kernel on this platform may not implement the PR_SET_FPEMU feature.\n");
-		}
+	if (retval == -1) {
+		if (errno == EINVAL)
+			fprintf(stderr, "ERROR: Kernel on this platform may not implement this prctl feature.\n");
+		else
+			fprintf(stderr, "Failed to %s \"fpemu\" value: %s\n",
+				((prctl_val==-1)?"get":"set"),strerror(errno));
 	}
 	return(retval);
 }
